#if FNODATDEF > 0
      integer bufsize
      parameter (bufsize=100000)
      type(buffer):: buf(bufsize)
#endif
